@@ -97,7 +97,7 @@ void ComicCreator::filterImages(QStringList& entries)
 {
     /// Sort case-insensitive, then remove non-image entries.
     QMap<QString, QString> entryMap;
-    Q_FOREACH(const QString& entry, entries) {
+    for (const QString& entry : qAsConst(entries)) {
         if (entry.endsWith(QLatin1String(".gif"), Qt::CaseInsensitive) ||
                 entry.endsWith(QLatin1String(".jpg"), Qt::CaseInsensitive) ||
                 entry.endsWith(QLatin1String(".jpeg"), Qt::CaseInsensitive) ||
@@ -161,7 +161,8 @@ void ComicCreator::getArchiveFileList(QStringList& entries, const QString& prefi
     const KArchiveDirectory *dir)
 {
     /// Recursively list all files in the ZIP archive into 'entries'.
-    Q_FOREACH (const QString& entry, dir->entries()) {
+    const auto dirEntries = dir->entries();
+    for (const QString& entry : dirEntries) {
         const KArchiveEntry *e = dir->entry(entry);
         if (e->isDirectory()) {
         getArchiveFileList(entries, prefix + entry + '/',
